import pandas as pd
from mimesis import Person

def quick_pandas_df(cols, num_rows):
    en = Person('en')
    data = []
    for i in range(num_rows):
        stuff = list(map(lambda col: getattr(en, col)(), cols))
        data.append(stuff)
    df = pd.DataFrame(data, columns = cols)
    return df


def pandas_df(funs, num_rows):
    data = []
    for i in range(num_rows):
        stuff = list(map(lambda f: f(), funs))
        data.append(stuff)
    col_names = list(map(lambda f: f.__name__, funs))
    df = pd.DataFrame(data, columns = col_names)
    return df




from pyspark.sql import SparkSession
from mimesis import Person
import itertools


def quick_pyspark_df(cols, num_rows, spark = SparkSession.builder.getOrCreate()):
    # valid_cols = ['first_name', 'last_name']
    # if not (set(cols) <= set(valid_cols)):
        # raise ValueError(f"The valid column values are '{valid_cols}'.  You tried to use these cols '{cols}'.")
    en = Person('en')
    def funs():
        return tuple(map(lambda col: getattr(en, col)(), cols))
    data = []
    for _ in itertools.repeat(None, num_rows):
        data.append(funs())
    return spark.createDataFrame(data, cols)


def pyspark_df(funs, num_rows, spark = SparkSession.builder.getOrCreate()):
    def functions():
        return tuple(map(lambda f: f(), funs))
    cols = list(map(lambda f: f.__name__, funs))
    data = []
    for _ in itertools.repeat(None, num_rows):
        data.append(functions())
    return spark.createDataFrame(data, cols)

